You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by tr...@apache.org on 2015/10/26 16:16:39 UTC

[1/2] qpid-dispatch git commit: DISPATCH-178 - Additional fix to include proton's PN_TRACE_RAW and PN_TRACE_DRV messages to be included in dispatch's TRACE logging

Repository: qpid-dispatch
Updated Branches:
  refs/heads/master e5135fc8f -> fed493c6a


DISPATCH-178 - Additional fix to include proton's PN_TRACE_RAW and PN_TRACE_DRV messages to be included in dispatch's TRACE logging


Project: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/repo
Commit: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/commit/60d3cf97
Tree: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/tree/60d3cf97
Diff: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/diff/60d3cf97

Branch: refs/heads/master
Commit: 60d3cf97d9cb99a9d0bdbe56ed58329f578a55dc
Parents: e5135fc
Author: ganeshmurthy <gm...@redhat.com>
Authored: Thu Oct 22 21:27:42 2015 -0400
Committer: ganeshmurthy <gm...@redhat.com>
Committed: Thu Oct 22 21:27:42 2015 -0400

----------------------------------------------------------------------
 src/server.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/qpid-dispatch/blob/60d3cf97/src/server.c
----------------------------------------------------------------------
diff --git a/src/server.c b/src/server.c
index f1f7343..bca3eb2 100644
--- a/src/server.c
+++ b/src/server.c
@@ -70,7 +70,8 @@ qd_error_t qd_entity_update_connection(qd_entity_t* entity, void *impl);
 static void qd_transport_tracer(pn_transport_t *transport, const char *message)
 {
     qd_connection_t *ctx = (qd_connection_t*) pn_transport_get_context(transport);
-    qd_log(ctx->server->log_source, QD_LOG_TRACE, "[%d]:%s", ctx->connection_id, message);
+    if (ctx)
+        qd_log(ctx->server->log_source, QD_LOG_TRACE, "[%d]:%s", ctx->connection_id, message);
 }
 
 static qd_error_t connection_entity_update_host(qd_entity_t* entity, qd_connection_t *conn)


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org
diff --git a/src/server.c b/src/server.c
index d53b64e..f1f7343 100644
--- a/src/server.c
+++ b/src/server.c
@@ -295,11 +295,11 @@ static void thread_process_listeners_LH(qd_server_t *qd_server)
 
         //
         // Proton pushes out its trace to qd_transport_tracer() which in turn writes a trace message to the qdrouter log
         // If trace level logging is enabled on the router set PN_TRACE_FRM on the proton transport
         //
         pn_transport_set_context(tport, ctx);
         if (qd_log_enabled(qd_server->log_source, QD_LOG_TRACE)) {
-            pn_transport_trace(tport, PN_TRACE_FRM);
+            pn_transport_trace(tport, PN_TRACE_DRV | PN_TRACE_FRM | PN_TRACE_RAW);
             pn_transport_set_tracer(tport, qd_transport_tracer);
         }
 
@@ -869,10 +869,10 @@ static void cxtr_try_open(void *context)
     //
     // Proton pushes out its trace to qd_transport_tracer() which in turn writes a trace message to the qdrouter log
     //
     // If trace level logging is enabled on the router set PN_TRACE_FRM on the proton transport
     pn_transport_set_context(tport, ctx);
     if (qd_log_enabled(ct->server->log_source, QD_LOG_TRACE)) {
-        pn_transport_trace(tport, PN_TRACE_FRM);
+        pn_transport_trace(tport, PN_TRACE_DRV | PN_TRACE_FRM | PN_TRACE_RAW);
         pn_transport_set_tracer(tport, qd_transport_tracer);
     }
 


---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@qpid.apache.org
For additional commands, e-mail: commits-help@qpid.apache.org


[2/2] qpid-dispatch git commit: DISPATCH-178 - Made the trace handler more defensive in case Proton loses the transport context.

Posted by tr...@apache.org.
DISPATCH-178 - Made the trace handler more defensive in case Proton loses the transport context.


Project: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/repo
Commit: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/commit/fed493c6
Tree: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/tree/fed493c6
Diff: http://git-wip-us.apache.org/repos/asf/qpid-dispatch/diff/fed493c6

Branch: refs/heads/master
Commit: fed493c6a5991ac4176b34c33fef2c230be4223a
Parents: 60d3cf9
Author: Ted Ross <tr...@redhat.com>
Authored: Mon Oct 26 11:15:24 2015 -0400
Committer: Ted Ross <tr...@redhat.com>
Committed: Mon Oct 26 11:15:24 2015 -0400

----------------------------------------------------------------------
 src/server.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/qpid-dispatch/blob/fed493c6/src/server.c
----------------------------------------------------------------------
@@ -295,11 +295,11 @@ static void thread_process_listeners_LH(qd_server_t *qd_server)
         //
         // Proton pushes out its trace to qd_transport_tracer() which in turn writes a trace message to the qdrouter log
-        // If trace level logging is enabled on the router set PN_TRACE_FRM on the proton transport
+        // If trace level logging is enabled on the router set PN_TRACE_DRV | PN_TRACE_FRM | PN_TRACE_RAW on the proton transport
         //
         pn_transport_set_context(tport, ctx);
@@ -869,10 +869,10 @@ static void cxtr_try_open(void *context)
     // Proton pushes out its trace to qd_transport_tracer() which in turn writes a trace message to the qdrouter log
     //
-    // If trace level logging is enabled on the router set PN_TRACE_FRM on the proton transport
+    // If trace level logging is enabled on the router set PN_TRACE_DRV | PN_TRACE_FRM | PN_TRACE_RAW on the proton transport
     pn_transport_set_context(tport, ctx);
     if (qd_log_enabled(ct->server->log_source, QD_LOG_TRACE)) {